Appendix D: Zope Resources
##########################

.. include:: includes/zope2_notice.rst

At the time of this writing there is a multitude of sources for Zope
information on the Internet and in print. We've collected a number of the most
important links which you can use to find out more about Zope.

Zope Web Sites
==============

`zope.dev <https://www.zope.dev>`_ is the official Zope website. It has
downloads, documentation, news, and lots of community resources.

Zope Documentation
==================

The main Zope documentation site is at https://zope.readthedocs.io/. It
contains technical documentation as well as the `Zope Book
<https://zope.readthedocs.io/en/latest/zopebook/index.html>`_ and the `Zope
Developer's Guide <https://zope.readthedocs.io/en/latest/zdgbook/index.html>`_.

(Other) Zope Books
==================

All of these books have been written for Zope version 2. Many concepts and
examples still apply to Zope versions 4 and up.

`The Zope Bible
<https://www.amazon.com/Zope-Bible-Michael-Bernstein/dp/0764548573/>`_
by Scott Robertson and Michael Bernstein, published April 2002.

`The Book of Zope
<https://www.amazon.com/Book-Zope-Beehive/dp/1886411573/>`_
by Beehive, published November 2001.

`The Zope Web Application Construction Kit
<https://www.amazon.com/Zope-Web-Application-Construction-Kit/dp/0672321335/>`_
edited by Martina Brockman, et. al., published October 2001.

`Zope: Web Application Development and Content Management
<https://www.amazon.com/Zope-Application-Development-Management-Landmark/dp/0735711100/>`_
edited by Steve Spicklemire et al., published December 2001.

`Zope: Timely, Practical, Reliable
<https://www.amazon.com/Zope/dp/0470844515/>`_
written by Pierre Julien Grizel.

`The Zope Book
<https://www.amazon.com/Zope-Book-Amos-Latteier/dp/0735711372/>`_
is the hardcover version of the original edition Zope Book on which the
first version of this text is based. The first edition was published in July
2001.

Mailing Lists
=============

Zope mailing lists are managed at `mail.zope.dev <https://mail.zope.dev/>`_ .

Python Information
==================

`Python.org <https://www.python.org>`_ has lots of information about Python
including a tutorial and reference documentation.
